****************
Mopidy-MFE
****************

`Mopidy <http://www.mopidy.com/>`_ web extension


Installation
============

Install by running::

    sudo pip install Mopidy-MFE



Project resources
=================

- `Source code <https://github.com/LukeMcDonnell/mopidy-MFE>`_
- `Issue tracker <https://github.com/LukeMcDonnell/mopidy-MFE/issues>`_
- `Development branch tarball <https://github.com/LukeMcDonnell/mopidy-MFE/tarball/master#egg=mopidy-MFE-dev>`_


Changelog
=========

v0.1.0 (2015-10-31)
-------------------

- Initial release.